import request from '@/utils/request'

// 更新
export function updateResource(query) {
  return request({
    url: '/work/step/resource',
    method: 'get',
    params: query
  })
}

// 查询工艺列表
export function listTechnology(query) {
  return request({
    url: '/work/technology/list',
    method: 'get',
    params: query
  })
}

// 查询角色列表
export function listMaterial1(query) {
  return request({
    url: '/work/material/list1',
    method: 'get',
    params: query
  })
}


// 获取消息数据
export function messageData(query) {
  return request({
    url: '/work/message/data',
    method: 'get',
    params: query
  })
}


// 获取消息数据
export function messageUpdate(query) {
  return request({
    url: '/work/message/update',
    method: 'get',
    params: query
  })
}

// 获取消息数据
export function materialClear() {
  return request({
    url: '/work/material/clear',
    method: 'get',
  })
}
